@@ -114,19 +114,18 @@ public:
 	 * reimplemented from @ref KChatBase
 	 * @return @ref KPlayer::name() for the player set by @ref setFromPlayer
 	 **/
-	virtual QString fromName() const;
+	QString fromName() const Q_DECL_OVERRIDE;
 
 
 public Q_SLOTS:
-	virtual void addMessage(const QString& fromName, const QString& text) { KChatBase::addMessage(fromName, text);}
+	void addMessage(const QString& fromName, const QString& text) Q_DECL_OVERRIDE { KChatBase::addMessage(fromName, text);}
 	virtual void addMessage(int fromId, const QString& text);
 
 	void slotReceiveMessage(int, const QByteArray&, quint32 receiver, quint32 sender);
 
 protected:
 	/**
-	 * @param id The ID of the sending entry, as returned by @ref
-	 * KChatBase::sendingEntry
+	 * @param id The ID of the sending entry, as returned by @ref KChatBase sendingEntry
 	 * @return True if the entry "send to all" was selected, otherwise false
 	 **/
 	bool isSendToAllMessage(int id) const;
@@ -135,10 +134,9 @@ protected:
 	 * Used to indicate whether a message shall be sent to a group of
 	 * players. Note that this was not yet implemented when this doc was
 	 * written so this description might be wrong. (FIXME)
-	 * @param id The ID of the sending entry, as returned by @ref
-	 * KChatBase::sendingEntry
-	 * @return True if the message is meant to be sent to a group (see @ref
-	 * KPlayer::group), e.g. if "send to my group" was selected.
+	 * @param id The ID of the sending entry, as returned by @ref KChatBase sendingEntry
+	 * @return True if the message is meant to be sent to a group (see @ref KPlayer::group
+         * ), e.g. if "send to my group" was selected.
 	 **/
 	bool isToGroupMessage(int id) const;
 
@@ -151,7 +149,7 @@ protected:
 	 *
 	 * See also toPlayerId
 	 * @param id The ID of the sending entry, as returned by
-	 * KChatBase::sendingEntry
+	 * @ref KChatBase sendingEntry
 	 * @return True if the message shall be sent to a special player,
 	 * otherwise false.
 	 **/
@@ -159,11 +157,11 @@ protected:
 
 	/**
 	 * @param id The ID of the sending entry, as returned by
-	 * KChatBase::sendingEntry
+	 * @ref KChatBase sendingEntry
 	 * @return The ID of the player (see KPlayer::id) the sending entry
-	 * belongs to. Note that the parameter id is an id as returned by ref
-	 * KChatBase::sendingEntry and the id this method returns is a
-	 * KPlayer ID. If isToPlayerMessage returns false this method
+	 * belongs to. Note that the parameter id is an id as returned by
+	 * @ref KChatBase sendingEntry and the id this method returns is a
+	 * KPlayer ID. If @ref isToPlayerMessage returns false this method
 	 * returns -1
 	 **/
 	int playerId(int id) const;
@@ -211,7 +209,7 @@ protected Q_SLOTS:
 	void slotReceivePrivateMessage(int msgid, const QByteArray& buffer, quint32 sender, KPlayer* me);
 
 protected:
-	virtual void returnPressed(const QString& text);
+	void returnPressed(const QString& text) Q_DECL_OVERRIDE;
 
 private:
 	void init(KGame* g, int msgid);
