@@ -22,7 +22,7 @@
 
 #include "libkdegamesprivate_export.h"
 
-#include <QtCore/QString>
+#include <QString>
 #include <QLoggingCategory>
 
 Q_DECLARE_LOGGING_CATEGORY(GAMES_LIB)
@@ -32,13 +32,13 @@ class QPixmap;
 
 /**
  * \class KGameTheme kgametheme.h <KGameTheme>
- * 
+ *
  * @short Class for loading theme files
  *
  * Essentially just a wrapper around a .desktop theme file. Load a file with
  * load() and then access its properties.
  *
- * For more advanced feaures like dynamic themes or custom game rules, it
+ * For more advanced features like dynamic themes or custom game rules, it
  * will likely be necessary to derive from this class
  *
  * @author Mauricio Piacentini
@@ -47,7 +47,7 @@ class QPixmap;
 class KDEGAMESPRIVATE_EXPORT KGameTheme
 {
     public:
-        KGameTheme(const QString &themeGroup = QLatin1String("KGameTheme"));
+        KGameTheme(const QString &themeGroup = QStringLiteral("KGameTheme"));
         virtual ~KGameTheme();
 
         /**
